{
    "skill": "{{ skillName }}",
    "icon": "time",
    "description": "{{ description }}",
    "slotTypes": [
        {
            "name": "DummySlot",
            "matchingStrictness": null,
            "automaticallyExtensible": false,
            "useSynonyms": true,
            "values": [
                {
                    "value": "foo",
                    "synonyms": ["bar"]
                }
            ]
        }
    ],
    "intents": [
        {
            "name": "Dummy",
            "description": "REMOVE this dummy intent!",
            "enabledByDefault": true,
            "utterances": [
                "dummy {foo:=>DummySlotName}",
                "bar"
            ],
            "slots": [
                {
                    "name": "DummySlotName",
                    "description": "dummy",
                    "required": false,
                    "type": "DummySlot",
                    "missingQuestion": ""
                }
            ]
        }
    ]
}